@@ -385,8 +385,11 @@ dataProcessPlots = function(
         list(PROTEIN = unique(Protein), PEPTIDE = "Run summary",
              TRANSITION = "Run summary", FEATURE = "Run summary",
              LABEL = "Endogenous", RUN = RUN,
-             ABUNDANCE = LogIntensities, FRACTION = 1)
-        ]
+             ABUNDANCE = LogIntensities, FRACTION = 1, 
+             UPPERBOUND = if("Variance" %in% names(.SD)) LogIntensities + 1.96 * sqrt(Variance) else NA_real_, # 95% confidence interval
+             LOWERBOUND = if("Variance" %in% names(.SD)) LogIntensities - 1.96 * sqrt(Variance) else NA_real_
+        )
+      ]
       if (is_censored) {
         quant$censored = FALSE
       }
